@@ -4,10 +4,10 @@ use super::ImageAssetData;
 use super::{BufferAsset, ImageAsset};
 use crate::assets::image::ImageAssetDataFormat;
 use crate::image_upload::{ImageUploadParams, IMAGE_UPLOAD_REQUIRED_SUBRESOURCE_ALIGNMENT};
-use crate::{
-    buffer_upload, image_upload, GpuImageData, GpuImageDataColorSpace, GpuImageDataLayer,
-    GpuImageDataMipLevel,
-};
+use crate::{buffer_upload, image_upload, GpuImageData, GpuImageDataColorSpace};
+#[cfg(feature = "basis-universal")]
+use crate::{GpuImageDataLayer, GpuImageDataMipLevel};
+#[cfg(feature = "basis-universal")]
 use basis_universal::{TranscodeParameters, TranscoderTextureFormat};
 use crossbeam_channel::{Receiver, Sender};
 use distill::loader::{storage::AssetLoadOp, LoadHandle};
@@ -100,6 +100,7 @@ pub struct PendingImageUpload {
 pub struct PendingBufferUpload {
     pub load_op: AssetLoadOp,
     pub upload_op: BufferUploadOp,
+    pub resource_type: RafxResourceType,
     pub data: Vec<u8>,
 }
 
@@ -141,7 +142,7 @@ struct InProgressUploadInner {
 
 struct InProgressUploadDebugInfo {
     upload_id: usize,
-    start_time: std::time::Instant,
+    start_time: rafx_base::Instant,
     size: u64,
     image_count: usize,
     buffer_count: usize,
@@ -420,6 +421,7 @@ impl UploadQueue {
         let result = buffer_upload::enqueue_load_buffer(
             &self.device_context,
             upload,
+            pending_buffer.resource_type,
             // self.transfer_queue.queue_family_index(),
             // self.graphics_queue.queue_family_index(),
             &pending_buffer.data,
@@ -537,7 +539,7 @@ impl UploadQueue {
                 buffer_count: in_flight_buffer_uploads.len(),
                 image_count: in_flight_image_uploads.len(),
                 size: upload.bytes_written(),
-                start_time: std::time::Instant::now(),
+                start_time: rafx_base::Instant::now(),
             };
 
             self.uploads_in_progress.push(InProgressUpload::new(
@@ -570,7 +572,7 @@ impl UploadQueue {
                         debug_info.size,
                         debug_info.image_count,
                         debug_info.buffer_count,
-                        (std::time::Instant::now() - debug_info.start_time).as_secs_f32(),
+                        debug_info.start_time.elapsed().as_secs_f32(),
                         debug_info.upload_id
                     );
 
@@ -585,7 +587,7 @@ impl UploadQueue {
                         debug_info.size,
                         debug_info.image_count,
                         debug_info.buffer_count,
-                        (std::time::Instant::now() - debug_info.start_time).as_secs_f32(),
+                        debug_info.start_time.elapsed().as_secs_f32(),
                         debug_info.upload_id
                     );
 
@@ -659,7 +661,7 @@ impl UploadManager {
 
         let generate_mips = request.asset.generate_mips_at_runtime;
 
-        let t0 = std::time::Instant::now();
+        let t0 = rafx_base::Instant::now();
         let image_data = match request.asset.format {
             ImageAssetDataFormat::RawRGBA32 => GpuImageData::new_simple(
                 request.asset.width,
@@ -667,6 +669,11 @@ impl UploadManager {
                 color_space.rgba8(),
                 request.asset.data,
             ),
+            #[cfg(not(feature = "basis-universal"))]
+            ImageAssetDataFormat::BasisCompressed => {
+                unimplemented!("Not built with basis-universal feature");
+            }
+            #[cfg(feature = "basis-universal")]
             ImageAssetDataFormat::BasisCompressed => {
                 let data = request.asset.data;
                 let mut transcoder = basis_universal::Transcoder::new();
@@ -754,7 +761,7 @@ impl UploadManager {
                 GpuImageData::new(layers, rafx_format)
             }
         };
-        let t1 = std::time::Instant::now();
+        let t1 = rafx_base::Instant::now();
 
         #[cfg(debug_assertions)]
         image_data.verify_state();
@@ -802,6 +809,7 @@ impl UploadManager {
                     request.result_tx,
                     self.buffer_upload_result_tx.clone(),
                 ),
+                resource_type: request.asset.resource_type,
                 data: request.asset.data,
             })
             .map_err(|_err| {
